﻿//------------------------------------------------------------------------------
// <copyright company="Kartones.Net">
//     Copyleft (c) Kartones 2009
// </copyright> 
//------------------------------------------------------------------------------

using System;

namespace KartonesNet.APIs
{
    /// <summary>
    /// HTML Table data formatter, using the first field as a link, for Google Analytics data
    /// </summary>
    public class GoogleAnalyticsTableWithLinkDataFormatter : IGoogleAnalyticsDataFormatter
    {
        #region Fields

        private readonly string host = "http://Kartones.net";
        private int fieldcounter = 0;

        #endregion

        #region Public Methods

        /// <summary>
        /// Tag to inject before each element
        /// </summary>
        /// <returns>Tag</returns>
        public string PreElementTag()
        {
            return "<tr>";
        }

        /// <summary>
        /// Tag to inject before each field of an element
        /// </summary>
        /// <returns>Tag</returns>
        public string PreFieldTag()
        {
            string html;

            switch (fieldcounter)
            {
                case 0:
                    html = "<td class='CommonListCellLeftMost'><a href='" + host;
                    break;
                case 1:
                    html = string.Empty;
                    break;
                default:
                    html = "<td class='CommonListCell'>";
                    break;
            }

            return html;
        }

        /// <summary>
        /// Tag to inject after each field of an element
        /// </summary>
        /// <returns>Tag</returns>
        public string PostFieldTag()
        {
            string html;

            switch (fieldcounter)
            {
                case 0:
                    html = "'>";
                    break;
                case 1:
                    html = "</a></td>";
                    break;
                default:
                    html = "</td>";
                    break;
            }

            fieldcounter++;

            return html;
        }

        /// <summary>
        /// Tag to inject after each element
        /// </summary>
        /// <returns>Tag</returns>
        public string PostElementTag()
        {
            fieldcounter = 0;
            return "</tr>";
        }

        #endregion
    }
}
